Class DefaultModuleMetadata
java.lang.Object
org.sonar.java.DefaultModuleMetadata
- All Implemented Interfaces:
ModuleMetadata
-
Constructor Summary
ConstructorsConstructorDescriptionDefaultModuleMetadata(org.sonar.api.batch.bootstrap.ProjectDefinition projectDefinition, org.sonar.api.config.Configuration configuration) -
Method Summary
Modifier and TypeMethodDescriptionReturns the Java version of the module being analyzed.Returns the module key of the module being analyzed.booleanDescribes whether input files should be parsed while ignoring unnamed split modules.
-
Constructor Details
-
DefaultModuleMetadata
public DefaultModuleMetadata(org.sonar.api.batch.bootstrap.ProjectDefinition projectDefinition, org.sonar.api.config.Configuration configuration)
-
-
Method Details
-
javaVersion
Description copied from interface:ModuleMetadataReturns the Java version of the module being analyzed.- Specified by:
javaVersionin interfaceModuleMetadata
-
moduleKey
Description copied from interface:ModuleMetadataReturns the module key of the module being analyzed.- Specified by:
moduleKeyin interfaceModuleMetadata
-
shouldIgnoreUnnamedModuleForSplitPackage
public boolean shouldIgnoreUnnamedModuleForSplitPackage()Description copied from interface:ModuleMetadataDescribes whether input files should be parsed while ignoring unnamed split modules.- Specified by:
shouldIgnoreUnnamedModuleForSplitPackagein interfaceModuleMetadata
-