Class Java25FeaturesTelemetryVisitor

java.lang.Object
org.sonar.java.ast.visitors.SubscriptionVisitor
org.sonar.java.ast.visitors.Java25FeaturesTelemetryVisitor
All Implemented Interfaces:
JavaCheck, JavaFileScanner, JavaVersionAwareVisitor

public final class Java25FeaturesTelemetryVisitor extends SubscriptionVisitor implements JavaVersionAwareVisitor
  • Constructor Details

    • Java25FeaturesTelemetryVisitor

      public Java25FeaturesTelemetryVisitor(Telemetry telemetry)
  • Method Details

    • nodesToVisit

      public List<Tree.Kind> nodesToVisit()
      Specified by:
      nodesToVisit in class SubscriptionVisitor
    • visitNode

      public void visitNode(Tree tree)
      Overrides:
      visitNode in class SubscriptionVisitor
    • isCompatibleWithJavaVersion

      public boolean isCompatibleWithJavaVersion(JavaVersion version)
      Description copied from interface: JavaVersionAwareVisitor
      Control if the check is compatible with the java version of the project being analyzed. The version used as parameter depends of the property sonar.java.source (6 or 1.6 for java 1.6, 7 or 1.7, etc.).
      Specified by:
      isCompatibleWithJavaVersion in interface JavaVersionAwareVisitor
      Parameters:
      version - The java version of the sources
      Returns:
      true if the check is compatible with detected java version and should be executed on sources, false otherwise.