Class InternalRange

java.lang.Object
org.sonar.java.model.location.InternalRange
All Implemented Interfaces:
Range

public class InternalRange extends Object implements Range
  • Constructor Details

  • Method Details

    • start

      public Position start()
      Specified by:
      start in interface Range
      Returns:
      the inclusive start position of the range. The character at this location is part of the range.
    • end

      public Position end()
      Specified by:
      end in interface Range
      Returns:
      the exclusive end position of the range. The character at this location is not part of the range.
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object