Package org.sonar.java.se.checks
Class CustomUnclosedResourcesCheck.CustomResourceConstraint
- java.lang.Object
-
- org.sonar.java.se.checks.CustomUnclosedResourcesCheck.CustomResourceConstraint
-
- All Implemented Interfaces:
Constraint
- Enclosing class:
- CustomUnclosedResourcesCheck
public class CustomUnclosedResourcesCheck.CustomResourceConstraint extends Object implements Constraint
-
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description StringvalueAsString()-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface org.sonar.java.se.constraint.Constraint
copyOver, hasPreciseValue, inverse, isValidWith
-
-
-
-
Method Detail
-
valueAsString
public String valueAsString()
- Specified by:
valueAsStringin interfaceConstraint- Returns:
- String representation of value encoded by constraint for purpose of flow message
-
-