Interface JavaFileScanner
- All Superinterfaces:
JavaCheck
- All Known Subinterfaces:
JavaResourceLocator
- All Known Implementing Classes:
CommentLinesVisitor, DefaultJavaResourceLocator, FileLinesVisitor, IssuableSubscriptionVisitor, Java25FeaturesTelemetryVisitor, JavaFilesCache, JWarning.Mapper, LinesOfCodeVisitor, Measurer, Measurer.TestFileMeasurer, SubscriptionVisitor, SyntaxHighlighterVisitor
-
Method Summary
Modifier and TypeMethodDescriptionvoidscanFile(JavaFileScannerContext context) Method called after parsing and semantic analysis has been done on file.default booleanscanWithoutParsing(InputFileScannerContext inputFileScannerContext) Scan based on the raw file and cached data (ie: No tree is available at this stage).
-
Method Details
-
scanFile
Method called after parsing and semantic analysis has been done on file.- Parameters:
context- Context of analysis containing the parsed tree.
-
scanWithoutParsing
Scan based on the raw file and cached data (ie: No tree is available at this stage). The rule should leverage data from the read cache. The rule should persist data to the write cache for future analyses.- Parameters:
inputFileScannerContext- The file that will eventually be scanned- Returns:
trueby default or if successful (ie: no further scanning is required).falseif the file cannot be scanned exhaustively without contents.
-