Interface ProfileRegistrar


@Beta @SonarLintSide @ServerSide public interface ProfileRegistrar
This class can be extended to provide additional rule keys in the builtin default quality profile.
  
    public void register(RegistrarContext registrarContext) {
      registrarContext.registerDefaultQualityProfileRules(ruleKeys);
    }
  
Note: It's possible to convert checkClass to RuleKey using:
  
    RuleKey.of(repositoryKey, RuleAnnotationUtils.getRuleKey(checkClass))
  
  • Nested Class Summary

    Nested Classes
    Modifier and Type
    Interface
    Description
    static interface 
     
  • Method Summary

    Modifier and Type
    Method
    Description
    void
    This method is called on server side and during an analysis to modify the builtin default quality profile for java.
  • Method Details

    • register

      void register(ProfileRegistrar.RegistrarContext registrarContext)
      This method is called on server side and during an analysis to modify the builtin default quality profile for java.