Interface ModuleMetadata
- All Known Implementing Classes:
DefaultModuleMetadata
Interface to access metadata about the module being analyzed by a Sensor.
For internal use only, this API will not be supported for custom plugins.
-
Method Summary
Modifier and TypeMethodDescriptionReturns the Java version of the module being analyzed.Returns the module key of the module being analyzed.booleanDescribes whether input files should be parsed while ignoring unnamed split modules.
-
Method Details
-
javaVersion
JavaVersion javaVersion()Returns the Java version of the module being analyzed. -
moduleKey
String moduleKey()Returns the module key of the module being analyzed. -
shouldIgnoreUnnamedModuleForSplitPackage
boolean shouldIgnoreUnnamedModuleForSplitPackage()Describes whether input files should be parsed while ignoring unnamed split modules.
-