Class Java25FeaturesTelemetryVisitor
java.lang.Object
org.sonar.java.ast.visitors.SubscriptionVisitor
org.sonar.java.ast.visitors.Java25FeaturesTelemetryVisitor
- All Implemented Interfaces:
JavaCheck, JavaFileScanner, JavaVersionAwareVisitor
public final class Java25FeaturesTelemetryVisitor
extends SubscriptionVisitor
implements JavaVersionAwareVisitor
-
Field Summary
Fields inherited from class SubscriptionVisitor
context -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanisCompatibleWithJavaVersion(JavaVersion version) Control if the check is compatible with the java version of the project being analyzed.voidMethods inherited from class SubscriptionVisitor
leaveFile, leaveNode, scanFile, scanTree, setContext, visitToken, visitTriviaMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface JavaFileScanner
scanWithoutParsing
-
Constructor Details
-
Java25FeaturesTelemetryVisitor
-
-
Method Details
-
nodesToVisit
- Specified by:
nodesToVisitin classSubscriptionVisitor
-
visitNode
- Overrides:
visitNodein classSubscriptionVisitor
-
isCompatibleWithJavaVersion
Description copied from interface:JavaVersionAwareVisitorControl if the check is compatible with the java version of the project being analyzed. The version used as parameter depends of the propertysonar.java.source(6 or 1.6 for java 1.6, 7 or 1.7, etc.).- Specified by:
isCompatibleWithJavaVersionin interfaceJavaVersionAwareVisitor- Parameters:
version- The java version of the sources- Returns:
- true if the check is compatible with detected java version and should be executed on sources, false otherwise.
-